==> ELAN-3_3_0-src.zip: ELAN-3.3.0-src/src/java/mpi/eudico/client/annotator/Constants.java <==
/*
 * File:     Constants.java
 * Project:  MPI Linguistic Application
 * Date:     12 December 2007
 *
 * Copyright (C) 2001-2008  Max Planck Institute for Psycholinguistics
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package mpi.eudico.client.annotator;

import java.awt.Color;
import java.awt.Font;


/**
 * DOCUMENT ME!
 * $Id: Constants.java 9173 2007-07-02 14:27:15Z hasloe $
 * @author $Author$
 * @version $Revision$
 */
public class Constants {
    /** Holds value of property DOCUMENT ME! */
    public static String USERHOME = System.getProperty("user.home");

    /** Holds value of property DOCUMENT ME! */
    public static String FILESEPARATOR = System.getProperty("file.separator");

    /** Holds value of property DOCUMENT ME! */
    public static String STRPROPERTIESFILE = USERHOME + FILESEPARATOR +
        ".elan.config";

    /** Holds value of property DOCUMENT ME! */
    public static String ELAN_DATA_DIR = USERHOME + FILESEPARATOR +
        ".elan_data";

    /** Holds value of property DOCUMENT ME! */
    public static Color DEFAULTBACKGROUNDCOLOR = new Color(230, 230, 230);

    /** Holds value of property DOCUMENT ME! */
    public static Color DEFAULTFOREGROUNDCOLOR = Color.black;

    /** Holds value of property DOCUMENT ME! */
    public static Color SELECTIONCOLOR = new Color(204, 204, 255);

    /** Holds value of property DOCUMENT ME! */
    public static Color CROSSHAIRCOLOR = Color.red;

    /** Holds value of property DOCUMENT ME! */
    public static Color ACTIVEANNOTATIONCOLOR = Color.blue;

    /** Holds value of property DOCUMENT ME! */
    public static Color MEDIAPLAYERCONTROLSLIDERSELECTIONCOLOR = Color.gray;

    /** Holds value of property DOCUMENT ME! */
    public static Color MEDIAPLAYERCONTROLSLIDERCROSSHAIRCOLOR = Color.red.darker();

    /** Holds value of property DOCUMENT ME! */
    public static Color SIGNALSTEREOBLENDEDCOLOR1 = Color.green;

    /** Holds value of property DOCUMENT ME! */
    public static Color SIGNALSTEREOBLENDEDCOLOR2 = Color.blue;

    /** Holds value of property DOCUMENT ME! */
    public static Color SIGNALCHANNELCOLOR = new Color(224, 224, 224);

    /** Holds value of property DOCUMENT ME! */
    public static Color SHAREDCOLOR1 = Color.orange;

    /** Holds value of property DOCUMENT ME! */
    public static Color SHAREDCOLOR2 = Color.yellow;

    /** Holds value of property DOCUMENT ME! */
    public static Color SHAREDCOLOR3 = Color.gray;

    /** Holds value of property DOCUMENT ME! */
    public static Color SHAREDCOLOR4 = Color.white;

    /** Holds value of property DOCUMENT ME! */
    public static Color ACTIVETIERCOLOR = new Color(230, 210, 210);

    /** Holds value of property DOCUMENT ME! */
    public static Color LIGHTBACKGROUNDCOLOR = new Color(240, 240, 240);

    /** Holds value of property DOCUMENT ME! */
    public static Font DEFAULTFONT = new Font("Arial Unicode MS", Font.PLAIN, 12);

    /** Holds value of property DOCUMENT ME! */
    public static Font SMALLFONT = new Font("Arial Unicode MS", Font.PLAIN, 10);

    /** Holds value of property DOCUMENT ME! */
    public static final int SCROLLMIN = 0;

    /** Holds value of property DOCUMENT ME! */
    public static final int SCROLLINCREMENT = 1;

    /** Holds value of property DOCUMENT ME! */
    public static final int COMBOBOX_VISIBLE_ROWS = 20;

    // backup interval constants

    /** Holds value of property DOCUMENT ME! */
    public static final Integer BACKUP_NEVER = new Integer(0);

    /** Holds value of property DOCUMENT ME! */
    public static final Integer BACKUP_1 = new Integer(60000);

    /** Holds value of property DOCUMENT ME! */
    public static final Integer BACKUP_5 = new Integer(300000);

    /** Holds value of property DOCUMENT ME! */
    public static final Integer BACKUP_10 = new Integer(600000);

    /** Holds value of property DOCUMENT ME! */
    public static final Integer BACKUP_20 = new Integer(1200000);

    /** Holds value of property DOCUMENT ME! */
    public static final Integer BACKUP_30 = new Integer(1800000);

    /** font sizes available in several viewers */
    public static final int[] FONT_SIZES = new int[] {
            8, 9, 10, 12, 14, 16, 18, 24, 36
        };

    // time format constants

    /** the hour/minutes/seconds/milliseconds format */
    public static final int HHMMSSMS = 100;

    /** the seconds/milliseconds format */
    public static final int SSMS = 101;

    /** the pure milliseconds format */
    public static final int MS = 102;

    /** the frame number format */
    public static final int HHMMSSFF = 103;

    /** Holds value of property DOCUMENT ME! */
    public static final String HHMMSSMS_STRING = "hh:mm:ss.ms";

    /** Holds value of property DOCUMENT ME! */
    public static final String SSMS_STRING = "ss.ms";

    /** Holds value of property DOCUMENT ME! */
    public static final String MS_STRING = "ms";

    /** Holds value of property DOCUMENT ME! */
    public static final String HHMMSSFF_STRING = "hh:mm:ss:ff";
}

==> ELAN-3_8_1-src.zip: ELAN-3.8.1-src/src/java/mpi/eudico/client/annotator/Constants.java <==
/*
 * File:     Constants.java
 * Project:  MPI Linguistic Application
 * Date:     25 August 2009
 *
 * Copyright (C) 2001-2009  Max Planck Institute for Psycholinguistics
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package mpi.eudico.client.annotator;

import java.awt.Color;
import java.awt.Font;


/**
 * DOCUMENT ME!
 * $Id: Constants.java 14929 2009-04-29 07:45:33Z hasloe $
 * @author $Author$
 * @version $Revision$
 */
public class Constants {
    /** Holds value of property DOCUMENT ME! */
    public static String USERHOME = System.getProperty("user.home");

    /** Holds value of property DOCUMENT ME! */
    public static String FILESEPARATOR = System.getProperty("file.separator");

    /** Holds value of property DOCUMENT ME! */
    public static String STRPROPERTIESFILE = USERHOME + FILESEPARATOR +
        ".elan.config";

    /** Holds value of property DOCUMENT ME! */
    public static String ELAN_DATA_DIR = USERHOME + FILESEPARATOR +
        ".elan_data";

    /** Holds value of property DOCUMENT ME! */
    public static Color DEFAULTBACKGROUNDCOLOR = new Color(230, 230, 230);

    /** Holds value of property DOCUMENT ME! */
    public static Color DEFAULTFOREGROUNDCOLOR = Color.black;

    /** Holds value of property DOCUMENT ME! */
    public static Color SELECTIONCOLOR = new Color(204, 204, 255);

    /** Holds value of property DOCUMENT ME! */
    public static Color CROSSHAIRCOLOR = Color.red;

    /** ALBERT */
    public static Color SEGMENTATIONCOLOR = Color.blue;

    /** Holds value of property DOCUMENT ME! */
    public static Color ACTIVEANNOTATIONCOLOR = Color.blue;

    /** Holds value of property DOCUMENT ME! */
    public static Color MEDIAPLAYERCONTROLSLIDERSELECTIONCOLOR = Color.gray;

    /** Holds value of property DOCUMENT ME! */
    public static Color MEDIAPLAYERCONTROLSLIDERCROSSHAIRCOLOR = Color.red.darker();

    /** Holds value of property DOCUMENT ME! */
    public static Color SIGNALSTEREOBLENDEDCOLOR1 = Color.green;

    /** Holds value of property DOCUMENT ME! */
    public static Color SIGNALSTEREOBLENDEDCOLOR2 = Color.blue;

    /** Holds value of property DOCUMENT ME! */
    public static Color SIGNALCHANNELCOLOR = new Color(224, 224, 224);

    /** Holds value of property DOCUMENT ME! */
    public static Color SHAREDCOLOR1 = Color.orange;

    /** Holds value of property DOCUMENT ME! */
    public static Color SHAREDCOLOR2 = Color.yellow;

    /** Holds value of property DOCUMENT ME! */
    public static Color SHAREDCOLOR3 = Color.gray;

    /** Holds value of property DOCUMENT ME! */
    public static Color SHAREDCOLOR4 = Color.white;

    /** Holds value of property DOCUMENT ME! */
    public static Color SHAREDCOLOR5 = new Color(128, 0, 128);

    /** Holds value of property DOCUMENT ME! */
    public static Color ACTIVETIERCOLOR = new Color(230, 210, 210);

    /** Holds value of property DOCUMENT ME! */
    public static Color LIGHTBACKGROUNDCOLOR = new Color(240, 240, 240);

    /** Holds value of property DOCUMENT ME! */
    public static Font DEFAULTFONT = new Font("Arial Unicode MS", Font.PLAIN, 12);

    /** Holds value of property DOCUMENT ME! */
    public static Font SMALLFONT = new Font("Arial Unicode MS", Font.PLAIN, 10);

    /** Holds value of property DOCUMENT ME! */
    public static final int SCROLLMIN = 0;

    /** Holds value of property DOCUMENT ME! */
    public static final int SCROLLINCREMENT = 1;

    /** Holds value of property DOCUMENT ME! */
    public static final int COMBOBOX_VISIBLE_ROWS = 20;

    // backup interval constants

    /** Holds value of property DOCUMENT ME! */
    public static final Integer BACKUP_NEVER = new Integer(0);

    /** Holds value of property DOCUMENT ME! */
    public static final Integer BACKUP_1 = new Integer(60000);

    /** Holds value of property DOCUMENT ME! */
    public static final Integer BACKUP_5 = new Integer(300000);

    /** Holds value of property DOCUMENT ME! */
    public static final Integer BACKUP_10 = new Integer(600000);

    /** Holds value of property DOCUMENT ME! */
    public static final Integer BACKUP_20 = new Integer(1200000);

    /** Holds value of property DOCUMENT ME! */
    public static final Integer BACKUP_30 = new Integer(1800000);

    /** font sizes available in several viewers */
    public static final int[] FONT_SIZES = new int[] {
            8, 9, 10, 12, 14, 16, 18, 24, 36
        };

    // time format constants

    /** the hour/minutes/seconds/milliseconds format */
    public static final int HHMMSSMS = 100;

    /** the seconds/milliseconds format */
    public static final int SSMS = 101;

    /** the pure milliseconds format */
    public static final int MS = 102;

    /** the frame number format */
    public static final int HHMMSSFF = 103;

    /** Holds value of property DOCUMENT ME! */
    public static final String HHMMSSMS_STRING = "hh:mm:ss.ms";

    /** Holds value of property DOCUMENT ME! */
    public static final String SSMS_STRING = "ss.ms";

    /** Holds value of property DOCUMENT ME! */
    public static final String MS_STRING = "ms";

    /** Holds value of property DOCUMENT ME! */
    public static final String HHMMSSFF_STRING = "hh:mm:ss:ff";

    /** HS May 2008: new location of ELAN data folder on the Mac. */
    static {
        if (System.getProperty("os.name").indexOf("Mac OS") > -1) {
            ELAN_DATA_DIR = USERHOME + FILESEPARATOR + "Library" +
                FILESEPARATOR + "Preferences" + FILESEPARATOR + "ELAN";
        }
    }
}
